@@ -1,4 +1,4 @@
-from .cli import Manot
+from .cli import manotAI
 import warnings
 
 warnings.filterwarnings("ignore")
